Package: tidyBdE
Title: Retrieve Data from 'Banco de España'
Version: 0.6.1
Authors@R: 
    person("Diego", "H. Herrero", , "dev.dieghernan@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-8457-4658"))
Description: Tools for retrieving time series data from 'Banco de España'
    ('BdE') as 'tibble' objects. 'Banco de España' is the national central
    bank and, within the framework of the Single Supervisory Mechanism
    ('SSM'), the supervisor of the Spanish banking system alongside the
    European Central Bank. This package is not sponsored, endorsed or
    administered by 'Banco de España'.
License: GPL (>= 3)
URL: https://ropenspain.github.io/tidyBdE/,
        https://github.com/rOpenSpain/tidyBdE
BugReports: https://github.com/rOpenSpain/tidyBdE/issues
Depends: R (>= 4.1.0)
Imports: dplyr (>= 0.7.0), ggplot2 (>= 3.5.0), readr (>= 1.0.0), scales
        (>= 1.1.0), tibble (>= 3.0.0), tidyr, utils
Suggests: knitr, lifecycle, quarto, testthat (>= 3.0.0)
VignetteBuilder: quarto
Config/Needs/coverage: covr
Config/Needs/website: cpp11, devtools, progress, reactable, remotes,
        styler, tidyverse, ropenspain/rostemplate
Config/roxygen2/markdown: TRUE
Config/roxygen2/version: 8.0.0
Config/testthat/edition: 3
Config/testthat/parallel: true
Copyright: See file inst/COPYRIGHTS
Encoding: UTF-8
LazyData: true
X-schema.org-applicationCategory: Macroeconomics
X-schema.org-isPartOf: https://ropenspain.es/
X-schema.org-keywords: api, bde, cran, ggplot2, macroeconomics, r,
        r-package, ropenspain, rstats, series-data, spain
NeedsCompilation: no
Packaged: 2026-05-21 12:37:18 UTC; diego
Author: Diego H. Herrero [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-8457-4658>)
Maintainer: Diego H. Herrero <dev.dieghernan@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-21 12:50:02 UTC
Built: R 4.6.0; ; 2026-05-25 04:28:05 UTC; unix
