# Generated by roxygen2: do not edit by hand

export(bde_catalog_load)
export(bde_catalog_search)
export(bde_catalog_update)
export(bde_check_access)
export(bde_ind_cpi_var)
export(bde_ind_euribor_12m_daily)
export(bde_ind_euribor_12m_monthly)
export(bde_ind_gdp_quarterly)
export(bde_ind_gdp_var)
export(bde_ind_ibex)
export(bde_ind_ibex_daily)
export(bde_ind_ibex_monthly)
export(bde_ind_population)
export(bde_ind_unemployment_rate)
export(bde_parse_dates)
export(bde_rose_pal)
export(bde_series_full_load)
export(bde_series_load)
export(bde_tidy_palettes)
export(bde_vivid_pal)
export(scale_color_bde_c)
export(scale_color_bde_d)
export(scale_colour_bde_c)
export(scale_colour_bde_d)
export(scale_fill_bde_c)
export(scale_fill_bde_d)
export(theme_tidybde)
importFrom(ggplot2,"%+replace%")
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,margin)
importFrom(ggplot2,rel)
importFrom(ggplot2,unit)
importFrom(utils,download.file)
importFrom(utils,read.csv2)
