#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
# import statements
#' @importFrom utils download.file read.csv2
#' @importFrom ggplot2 unit element_rect element_text element_blank element_line
NULL
