# bde_vivid_pal

    Code
      vpal <- bde_vivid_pal()(3)
    Condition
      Warning:
      `bde_vivid_pal()` was deprecated in tidyBdE 0.3.5.
      i Please use `bde_tidy_palettes()` instead.

# bde_rose_pal

    Code
      vpal <- bde_rose_pal()(4)
    Condition
      Warning:
      `bde_rose_pal()` was deprecated in tidyBdE 0.3.5.
      i Please use `bde_tidy_palettes()` instead.

